@@ -13,6 +13,7 @@ from .types import FileCategory, File, ReadResult
 
 from .__util_storage import Storage
 from .__util_datalake import Datalake
+from .__util_es_datalake import es_datalake_search_eql
 from .__util_log import Log
 from .__util_merge import merge_arrays, merge_objects
 from .__util_metadata import FIELDS
@@ -359,6 +360,10 @@ class Context:
         
         return new_file
 
+    @wrap_log('context.search_eql')
+    def search_eql(self, payload):
+        return es_datalake_search_eql(payload)
+
 
 def output_response(storage, response, correlation_id):
     storage.writeObject({**response, 'id': correlation_id})
